spacepy.seapy.multisea — SpacePy v0.1.5 Manual

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »

# spacepy.seapy.multisea

`spacepy.seapy.` `multisea`(dictobj, n_cols=1, epochline=False, usrlimx=, []usrlimy=, []xunits='', show=True, zunits='', zlog=True, figsize=None, dpi=300)

  Function to create multipanel plot of superposed epoch analyses.

  Parameters: | Dictionary of Sea objects (from superposedepoch.seadict()). :
  Returns: | Plot of input object median and bounds (ci, mad, quartiles - see sea()). : If keyword ‘show’ is False, output is a plot object. :
  Other Parameters:
  | - epochline (default = False) - put vertical line at zero epoch. : usrlimy (default = []) - override automatic y-limits on plot (same for all plots). show (default = True) - shows plot; set to false to output plot object to variable x/zunits - Units for labeling x and z axes, if required figsize - tuple of (width, height) in inches dpi (default=300) - figure resolution in dots per inch n_cols - Number of columns: not yet implemented.

### Navigation

- index
- modules |
- modules |
- next |
- previous |
- homepage|
- search|
- documentation »
- SeaPy - Superposed Epoch in Python »